@@ -307,24 +307,7 @@ class Event(IntFlag):
             # add EVENT_ prefix
             return "EVENT_" + name
 
-    CONNECTED = 0x0001
-    CONNECT_DELAYED = 0x0002
-    CONNECT_RETRIED = 0x0004
-    LISTENING = 0x0008
-    BIND_FAILED = 0x0010
-    ACCEPTED = 0x0020
-    ACCEPT_FAILED = 0x0040
-    CLOSED = 0x0080
-    CLOSE_FAILED = 0x0100
-    DISCONNECTED = 0x0200
-    MONITOR_STOPPED = 0x0400
-    ALL = 0xFFFF
-
-    HANDSHAKE_FAILED_NO_DETAIL = 0x0800
-    HANDSHAKE_SUCCEEDED = 0x1000
-    HANDSHAKE_FAILED_PROTOCOL = 0x2000
-    HANDSHAKE_FAILED_AUTH = 0x4000
-
+    PROTOCOL_ERROR_WS_UNSPECIFIED = 0x30000000
     PROTOCOL_ERROR_ZMTP_UNSPECIFIED = 0x10000000
     PROTOCOL_ERROR_ZMTP_UNEXPECTED_COMMAND = 0x10000001
     PROTOCOL_ERROR_ZMTP_INVALID_SEQUENCE = 0x10000002
@@ -346,11 +329,30 @@ class Event(IntFlag):
     PROTOCOL_ERROR_ZAP_BAD_VERSION = 0x20000003
     PROTOCOL_ERROR_ZAP_INVALID_STATUS_CODE = 0x20000004
     PROTOCOL_ERROR_ZAP_INVALID_METADATA = 0x20000005
-    PROTOCOL_ERROR_WS_UNSPECIFIED = 0x30000000
+
+    # define event types _after_ overlapping protocol error masks
+    CONNECTED = 0x0001
+    CONNECT_DELAYED = 0x0002
+    CONNECT_RETRIED = 0x0004
+    LISTENING = 0x0008
+    BIND_FAILED = 0x0010
+    ACCEPTED = 0x0020
+    ACCEPT_FAILED = 0x0040
+    CLOSED = 0x0080
+    CLOSE_FAILED = 0x0100
+    DISCONNECTED = 0x0200
+    MONITOR_STOPPED = 0x0400
+
+    HANDSHAKE_FAILED_NO_DETAIL = 0x0800
+    HANDSHAKE_SUCCEEDED = 0x1000
+    HANDSHAKE_FAILED_PROTOCOL = 0x2000
+    HANDSHAKE_FAILED_AUTH = 0x4000
+
+    ALL_V1 = 0xFFFF
+    ALL = ALL_V1
 
     # DRAFT Socket monitoring events
     PIPES_STATS = 0x10000
-    ALL_V1 = ALL
     ALL_V2 = ALL_V1 | PIPES_STATS
 
 
