@@ -2,13 +2,10 @@
 # Distributed under the terms of the Modified BSD License.
 
 
-from random import Random
 import time
-from unittest import TestCase
 
 import zmq
-
-from zmq.tests import BaseZMQTestCase, have_gevent, GreenTest
+from zmq.tests import BaseZMQTestCase, GreenTest, have_gevent
 
 
 class TestPubSub(BaseZMQTestCase):
@@ -23,7 +20,7 @@ class TestPubSub(BaseZMQTestCase):
         msg1 = b'message'
         s1.send(msg1)
         msg2 = s2.recv()  # This is blocking!
-        self.assertEqual(msg1, msg2)
+        assert msg1 == msg2
 
     def test_topic(self):
         s1, s2 = self.create_bound_pair(zmq.PUB, zmq.SUB)
@@ -35,8 +32,10 @@ class TestPubSub(BaseZMQTestCase):
         msg1 = b'xmessage'
         s1.send(msg1)
         msg2 = s2.recv()
-        self.assertEqual(msg1, msg2)
+        assert msg1 == msg2
+
 
 if have_gevent:
+
     class TestPubSubGreen(GreenTest, TestPubSub):
         pass
